Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(73)

Unified Diff: src/compiler/access-builder.h

Issue 2079613003: [generators] Implement %GeneratorGetSourcePosition. (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: rename again, and move subtraction to runtime Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/arm64/builtins-arm64.cc ('k') | src/compiler/access-builder.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/compiler/access-builder.h
diff --git a/src/compiler/access-builder.h b/src/compiler/access-builder.h
index 7412a1d36ca4abd8abcb099e32704fd958ed1546..834522531002347232952998e9baacf8eafe2bb7 100644
--- a/src/compiler/access-builder.h
+++ b/src/compiler/access-builder.h
@@ -58,8 +58,8 @@ class AccessBuilder final : public AllStatic {
// Provides access to JSGeneratorObject::continuation() field.
static FieldAccess ForJSGeneratorObjectContinuation();
- // Provides access to JSGeneratorObject::input() field.
- static FieldAccess ForJSGeneratorObjectInput();
+ // Provides access to JSGeneratorObject::input_or_debug_pos() field.
+ static FieldAccess ForJSGeneratorObjectInputOrDebugPos();
// Provides access to JSGeneratorObject::operand_stack() field.
static FieldAccess ForJSGeneratorObjectOperandStack();
« no previous file with comments | « src/arm64/builtins-arm64.cc ('k') | src/compiler/access-builder.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698